MatchMakerMonitoring.save_data() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.save_data()

MatchMakerMonitoring.save_data(level: int = 1, sync: bool = False)

  Saves current experiment data.

  Collects the current experimental data and calls the experiment’s main SavingAgentController to save the data with all SavingAgents.

  Parameters

    - level – Level of the saving task. High level means high importance. If the level is below a SavingAgent’s activation level, that agent will not be used for processing this task. Defaults to 1.

    - sync – If True, the saving task will be prioritised and the experiment will pause until the task was fully completed. Should be used carefully. Defaults to False.

  Notes

  Note that this function will be called automatically on every move in the experiment. Only call it yourself if it is really necessary.